Description
================

PyPEC aims at Fitting PEC data with an graphical interface. 
The program was initially developped in Python 2.7 during my PhD from 2012 to 2015 and the code is available on github
`PyPEC (Python 2) <https://github.com/MilanSkocic/PyPEC>`_. 

In 2016, the code was rewritten in Python 3 at the end of my PhD with slight modifications of the original. The code 
remained untouched for almost 3 years and is now again under development in this repository.

The first release after migrating to github will serve as a backup for the version developed during my
PhD with completed documentation. 

Installation
==================
See  ``INSTALL.txt``.


Dependencies
===================
See ``requirements.txt``.


License information
===========================

See ``LICENSE.txt`` for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.
